=========================
Template tags and filters
=========================


.. note::

 In each of the following examples it is understood that you have already loaded the ``django_bootstrap5``
 template tag library, placing the code below at the beginning of each template in which the ``django_bootstrap5``
 template tag library will be used. Read the :doc:`installation` and :doc:`quickstart` sections to understand how
 to accomplish this.


bootstrap_form
~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_form


bootstrap_form_errors
~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_form_errors


bootstrap_formset
~~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_formset


bootstrap_formset_errors
~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_formset_errors


bootstrap_field
~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_field


bootstrap_label
~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_label


bootstrap_button
~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_button


bootstrap_alert
~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_alert


bootstrap_messages
~~~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_messages


bootstrap_pagination
~~~~~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_pagination


bootstrap_javascript_url
~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_javascript_url


bootstrap_css_url
~~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_css_url


bootstrap_css
~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_css


bootstrap_javascript
~~~~~~~~~~~~~~~~~~~~

.. autofunction:: django_bootstrap5.templatetags.django_bootstrap5.bootstrap_javascript
